@@ -10,9 +10,9 @@
  *		Internet: MRC@CAC.Washington.EDU
  *
  * Date:	12 December 1993
- * Last Edited:	28 August 1995
+ * Last Edited:	3 April 1996
  *
- * Copyright 1995 by Mark Crispin
+ * Copyright 1996 by Mark Crispin
  *
  *  Permission to use, copy, modify, and distribute this software and its
  * documentation for any purpose and without fee is hereby granted, provided
@@ -171,7 +171,7 @@ void nntp_find_all_bboards (MAILSTREAM *stream,char *pat)
       patx = pat;		/* use entire specification */
     }
 				/* ask server for all active newsgroups */
-    if (!(smtp_send (LOCAL->nntpstream,"LIST","ACTIVE") == NNTPGLIST)) return;
+    if (!(nntp_send (LOCAL->nntpstream,"LIST","ACTIVE") == NNTPGLIST)) return;
 				/* process data until we see final dot */
     while ((s = tcp_getline (LOCAL->nntpstream->tcpstream)) && *s != '.') {
 				/* tie off after newsgroup name */
@@ -315,7 +315,7 @@ MAILSTREAM *nntp_mopen (MAILSTREAM *stream)
   }
   if (nstream) {		/* now try to open newsgroup */
     if ((!stream->halfopen) &&	/* open the newsgroup if not halfopen */
-	((smtp_send (nstream,"GROUP",mb.mailbox) != NNTPGOK) ||
+	((nntp_send (nstream,"GROUP",mb.mailbox) != NNTPGOK) ||
 	 ((k = strtol (nstream->reply + 4,&s,10)) < 0) ||
 	 ((i = strtol (s,&s,10)) < 0) || ((j = strtol (s,&s,10)) < 0) ||
 	 (nmsgs = i | j ? 1 + j - i : 0) < 0)) {
@@ -341,8 +341,8 @@ MAILSTREAM *nntp_mopen (MAILSTREAM *stream)
       if (nmsgs) {		/* find what messages exist */
 	LOCAL->number = (unsigned long *) fs_get (nmsgs*sizeof(unsigned long));
 	sprintf (tmp,"%ld-%ld",i,j);
-	if ((smtp_send (nstream,"LISTGROUP",mb.mailbox) == NNTPGOK) ||
-	    (smtp_send (nstream,"XHDR Date",tmp) == NNTPHEAD)) {
+	if ((nntp_send (nstream,"LISTGROUP",mb.mailbox) == NNTPGOK) ||
+	    (nntp_send (nstream,"XHDR Date",tmp) == NNTPHEAD)) {
 	  for (i = 0; (s = tcp_getline (nstream->tcpstream)) && strcmp (s,".");
 	       i++) {		/* initialize c-client/NNTP map */
 	    if (i < nmsgs) LOCAL->number[i] = atol (s);
@@ -350,8 +350,9 @@ MAILSTREAM *nntp_mopen (MAILSTREAM *stream)
 	  }
 	  if (s) fs_give ((void **) &s);
 	  if (i != nmsgs) {	/* found holes? */
-	    nmsgs = i;		/* set new size */
-	    fs_resize ((void **) &LOCAL->number,nmsgs*sizeof (unsigned long));
+	    if (nmsgs = i)
+	      fs_resize ((void **) &LOCAL->number,nmsgs*sizeof(unsigned long));
+	    else fs_give ((void **) &LOCAL->number);
 	  }
 	}
 				/* assume c-client/NNTP map is entire range */
@@ -493,7 +494,7 @@ char *nntp_fetchheader (MAILSTREAM *stream,long msgno)
   long m = msgno - 1;
   if (!LOCAL->header[m]) {	/* fetch header if don't have already */
     sprintf (tmp,"%ld",LOCAL->number[m]);
-    if (smtp_send (LOCAL->nntpstream,"HEAD",tmp) == NNTPHEAD)
+    if (nntp_send (LOCAL->nntpstream,"HEAD",tmp) == NNTPHEAD)
       LOCAL->header[m] = nntp_slurp (stream);
 				/* failed, mark as deleted */
     else mail_elt (stream,msgno)->deleted = T;
@@ -529,7 +530,7 @@ char *nntp_fetchtext_work (MAILSTREAM *stream,long msgno)
   long m = msgno - 1;
   if (!LOCAL->body[m]) {	/* fetch body if don't have already */
     sprintf (tmp,"%ld",LOCAL->number[m]);
-    if (smtp_send (LOCAL->nntpstream,"BODY",tmp) == NNTPBODY)
+    if (nntp_send (LOCAL->nntpstream,"BODY",tmp) == NNTPBODY)
       LOCAL->body[m] = nntp_slurp (stream);
 				/* failed, mark as deleted */
     else mail_elt (stream,msgno)->deleted = T;
@@ -786,7 +787,7 @@ long nntp_ping (MAILSTREAM *stream)
   /* Kludge alert: SMTPSOFTFATAL is 421 which is used in NNTP to mean ``No
    * next article in this group''.  Hopefully, no NNTP server will send this
    * in response to a STAT */
-  return (smtp_send (LOCAL->nntpstream,"STAT",NIL) != SMTPSOFTFATAL);
+  return (nntp_send (LOCAL->nntpstream,"STAT",NIL) != SMTPSOFTFATAL);
 }
 
 
