@@ -10,7 +10,7 @@
  *		Internet: MRC@CAC.Washington.EDU
  *
  * Date:	1 August 1988
- * Last Edited:	7 February 1996
+ * Last Edited:	4 April 1996
  *
  * Copyright 1996 by the University of Washington
  *
@@ -45,6 +45,11 @@
 #include <sys/file.h>
 
 
+/* SCO gets this wrong */
+
+#define setpgrp(a,b) Setpgrp(a,b)
+
+
 /* Different names, equivalent things in BSD and SysV */
 
 #define L_SET SEEK_SET
