@@ -1,5 +1,5 @@
 #if	!defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: os_unix.c,v 4.101 1996/03/17 23:00:08 mikes Exp $";
+static char rcsid[] = "$Id: os_unix.c,v 4.106 1996/04/10 05:23:36 hubert Exp $";
 #endif
 /*
  * Program:	Operating system dependent routines - Ultrix 4.1
@@ -56,7 +56,7 @@ static char rcsid[] = "$Id: os_unix.c,v 4.101 1996/03/17 23:00:08 mikes Exp $";
 #endif
 #if	defined(POSIX)
 #include	<termios.h>
-#if	defined(a32) || defined(cvx)
+#if	defined(a32) || defined(cvx) || defined(osf)
 #include	<sys/ioctl.h>
 #endif
 #else
@@ -1009,7 +1009,8 @@ bktoshell()		/* suspend MicroEMACS and wait to wake up */
 	    vttidy();
 	    movecursor(0, 0);
 	    (*term.t_eeop)();
-	    printf("\n\n\nUse \"exit\" to return to Pico\n");
+	    printf("\n\n\nUse \"exit\" to return to Pi%s\n",
+		   (gmode & MDBRONLY) ? "lot" : "co");
 	}
 
 	system((shell = (char *)getenv("SHELL")) ? shell : "/bin/csh");
@@ -1028,7 +1029,8 @@ bktoshell()		/* suspend MicroEMACS and wait to wake up */
 	    movecursor(term.t_nrow, 0);
 	    peeol();
 	    movecursor(term.t_nrow, 0);
-	    printf("\n\n\nUse \"fg\" to return to Pico\n");
+	    printf("\n\n\nUse \"fg\" to return to Pi%s\n",
+		   (gmode & MDBRONLY) ? "lot" : "co");
 	    ttclose();
 	}
 
@@ -1060,6 +1062,7 @@ rtfrmshell()
 
     ttopen();
     ttresize();
+    pclear(0, term.t_nrow);
     refresh(0, 1);
 #endif
 }
@@ -1107,7 +1110,7 @@ unsigned char okinfname[32] = {
       0,    0, 			/* ^@ - ^G, ^H - ^O  */
       0,    0,			/* ^P - ^W, ^X - ^_  */
       0x80, 0x17,		/* SP - ' ,  ( - /   */
-      0xff, 0xc0,		/*  0 - 7 ,  8 - ?   */
+      0xff, 0xc4,		/*  0 - 7 ,  8 - ?   */
       0x7f, 0xff,		/*  @ - G ,  H - O   */
       0xff, 0xe1,		/*  P - W ,  X - _   */
       0x7f, 0xff,		/*  ` - g ,  h - o   */
@@ -1313,7 +1316,7 @@ char *
 errstr(err)
 int err;
 {
-#ifndef	neb
+#if !defined(neb) && !defined(BSDI2)
     extern char *sys_errlist[];
 #endif
     extern int  sys_nerr;
