@@ -1,5 +1,5 @@
 #if	!defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: region.c,v 4.12 1994/07/07 01:29:01 mikes Exp $";
+static char rcsid[] = "$Id: region.c,v 4.18 1996/03/15 07:41:11 hubert Exp $";
 #endif
 /*
  * Program:	Region management routines
@@ -15,28 +15,16 @@ static char rcsid[] = "$Id: region.c,v 4.12 1994/07/07 01:29:01 mikes Exp $";
  *
  * Please address all bugs and comments to "pine-bugs@cac.washington.edu"
  *
- * Copyright 1991-1994  University of Washington
  *
- *  Permission to use, copy, modify, and distribute this software and its
- * documentation for any purpose and without fee to the University of
- * Washington is hereby granted, provided that the above copyright notice
- * appears in all copies and that both the above copyright notice and this
- * permission notice appear in supporting documentation, and that the name
- * of the University of Washington not be used in advertising or publicity
- * pertaining to distribution of the software without specific, written
- * prior permission.  This software is made available "as is", and
- * THE UNIVERSITY OF WASHINGTON DISCLAIMS ALL WARRANTIES, EXPRESS OR IMPLIED,
- * WITH REGARD TO THIS SOFTWARE, INCLUDING WITHOUT LIMITATION ALL IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE, AND IN
- * NO EVENT SHALL THE UNIVERSITY OF WASHINGTON BE LIABLE FOR ANY SPECIAL,
- * INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
- * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, TORT
- * (INCLUDING NEGLIGENCE) OR STRICT LIABILITY, ARISING OUT OF OR IN CONNECTION
- * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
- *
- * Pine and Pico are trademarks of the University of Washington.
- * No commercial use of these trademarks may be made without prior
- * written permission of the University of Washington.
+ * Pine and Pico are registered trademarks of the University of Washington.
+ * No commercial use of these trademarks may be made without prior written
+ * permission of the University of Washington.
+ * 
+ * Pine, Pico, and Pilot software and its included text are Copyright
+ * 1989-1996 by the University of Washington.
+ * 
+ * The full text of our legal notices is contained in the file called
+ * CPYRIGHT, included with this distribution.
  *
  */
 /*
@@ -47,8 +35,9 @@ static char rcsid[] = "$Id: region.c,v 4.12 1994/07/07 01:29:01 mikes Exp $";
  * internal use.
  */
 #include        <stdio.h>
-#include	"estruct.h"
+#include	"osdep.h"
 #include	"pico.h"
+#include	"estruct.h"
 #include        "edef.h"
 
 /*
@@ -91,7 +80,7 @@ killregion(f, n)
     mswin_allowcopycut(NULL);
 #endif
 
-    if(ldelete((int)region.r_size, TRUE)){
+    if(ldelete(region.r_size, TRUE)){
 	if(curwp->w_dotp == curwp->w_linep && curwp->w_dotp == curbp->b_linep){
 	    curwp->w_force = 0;		/* Center dot. */
 	    curwp->w_flag |= WFFORCE;
@@ -247,8 +236,8 @@ register REGION *rp;
 {
     register LINE   *flp;
     register LINE   *blp;
-    int    fsize;
-    register int    bsize;
+    long	    fsize;
+    register long   bsize;
 
     if (curwp->w_markp == NULL) {
 	return (FALSE);
@@ -276,11 +265,11 @@ register REGION *rp;
 	    if (flp == curwp->w_markp) {
 		rp->r_linep = curwp->w_dotp;
 		rp->r_offset = curwp->w_doto;
-		rp->r_size = fsize+curwp->w_marko;
+		rp->r_size = fsize + curwp->w_marko;
 		return (TRUE);
 	    }
 
-	    fsize += llength(flp)+1;
+	    fsize += llength(flp) + 1;
 	}
 
 	if (lback(blp) != curbp->b_linep) {
