@@ -1,5 +1,5 @@
 #if !defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: mailpart.c,v 4.112 1996/03/15 07:13:42 hubert Exp $";
+static char rcsid[] = "$Id: mailpart.c,v 4.113 1996/03/25 20:20:57 mikes Exp $";
 #endif
 /*----------------------------------------------------------------------
 
@@ -107,7 +107,7 @@ int	  df_trigger_cmp_text PROTO((char *, char *));
 int	  df_trigger_cmp_lwsp PROTO((char *, char *));
 int	  df_trigger_cmp_start PROTO((char *, char *));
 int	  df_static_trigger PROTO((BODY *));
-int	  df_valid_command PROTO((char *));
+int	  df_valid_command PROTO((char **));
 char	 *dfilter PROTO((char *, STORE_S *, gf_io_t, filter_t *));
 
 
@@ -997,7 +997,7 @@ save_attachment(qline, msgno, a)
             continue;
         }
 
-#if defined(DOS) || defined(OS2)
+#if	defined(DOS) || defined(OS2)
 	if(is_absolute_path(full_filename)){
 	    fixpath(full_filename, MAXPATH);
 	}
@@ -2053,7 +2053,7 @@ df_static_trigger(body)
 	/*
 	 * make sure cmd exists!  NOTE: success overloaded
 	 */
-	if(!(success && df_valid_command(cmd))){
+	if(!(success && df_valid_command(&cmd))){
 	    success = 0;
 	    if(cmd)
 	      fs_give((void **)&cmd);
@@ -2080,7 +2080,7 @@ build_trigger_list()
     trailp = &tp;
     for(l = ps_global->VAR_DISPLAY_FILTERS ; l && *l; l++){
 	get_pair(*l, &test, &cmd, 1);
-	if(test && df_valid_command(cmd)){
+	if(test && df_valid_command(&cmd)){
 	    *trailp	  = (struct triggers *)fs_get(sizeof(struct triggers));
 	    (*trailp)->cmp = df_trigger_cmp_text;
 	    str		   = test;
@@ -2204,23 +2204,51 @@ df_trigger_cmp_start(s1, s2)
 
 
 /*
- * df_valid_command - make sure argv[0] of command really exists
+ * df_valid_command - make sure argv[0] of command really exists.
+ *		      "cmd" is required to be an alloc'd string since
+ *		      it will get realloc'd if the command's path is
+ *		      expanded.
  */
 int
 df_valid_command(cmd)
-    char *cmd;
+    char **cmd;
 {
-    int   rv = 0;
-    char *p;
+    int  i;
+    char cpath[MAXPATH+1], *p;
 
-    if(p = strchr(cmd, ' '))
-      *p = '\0';
+    /*
+     * copy cmd to build expanded path if necessary.
+     */
+    for(i = 0; cpath[i] = (*cmd)[i]; i++)
+      if(isspace((*cmd)[i])){
+	  cpath[i] = '\0';		/* tie off command's path*/
+	  break;
+      }
 
-    rv = is_absolute_path(cmd) && can_access(cmd, EXECUTE_ACCESS) == 0;
-    if(p)
-      *p = ' ';
+#if	defined(DOS) || defined(OS2)
+    if(is_absolute_path(cpath)){
+	fixpath(cpath, MAXPATH);
+	p = (char *) fs_get(strlen(cpath) + strlen(&(*cmd)[i]) + 1);
+	strcpy(p, cpath);		/* copy new path */
+	strcat(p, &(*cmd)[i]);		/* and old args */
+	fs_give((void **) cmd);		/* free it */
+	*cmd = p;			/* and assign new buf */
+    }
+#else
+    if(cpath[0] == '~'){
+	if(fnexpand(cpath, MAXPATH)){
+	    p = (char *) fs_get(strlen(cpath) + strlen(&(*cmd)[i]) + 1);
+	    strcpy(p, cpath);		/* copy new path */
+	    strcat(p, &(*cmd)[i]);	/* and old args */
+	    fs_give((void **) cmd);	/* free it */
+	    *cmd = p;			/* and assign new buf */
+	}
+	else
+	  return(FALSE);
+    }
+#endif
 
-    return(rv);
+    return(is_absolute_path(cpath) && can_access(cpath, EXECUTE_ACCESS) == 0);
 }
 
 
