@@ -1,6 +1,6 @@
 #line 2 "osdep/os-dos.h"
 /*----------------------------------------------------------------------
-  $Id: os-dos.h,v 5.23 1994/08/27 02:40:01 mikes Exp $
+  $Id: os-dos.h,v 5.44 1996/04/02 22:52:59 mikes Exp $
 
             T H E    P I N E    M A I L   S Y S T E M
 
@@ -15,28 +15,17 @@
 
    Please address all bugs and comments to "pine-bugs@cac.washington.edu"
 
-   Copyright 1989-1994  University of Washington
 
-    Permission to use, copy, modify, and distribute this software and its
-   documentation for any purpose and without fee to the University of
-   Washington is hereby granted, provided that the above copyright notice
-   appears in all copies and that both the above copyright notice and this
-   permission notice appear in supporting documentation, and that the name
-   of the University of Washington not be used in advertising or publicity
-   pertaining to distribution of the software without specific, written
-   prior permission.  This software is made available "as is", and
-   THE UNIVERSITY OF WASHINGTON DISCLAIMS ALL WARRANTIES, EXPRESS OR IMPLIED,
-   WITH REGARD TO THIS SOFTWARE, INCLUDING WITHOUT LIMITATION ALL IMPLIED
-   WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE, AND IN
-   NO EVENT SHALL THE UNIVERSITY OF WASHINGTON BE LIABLE FOR ANY SPECIAL,
-   INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
-   LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, TORT
-   (INCLUDING NEGLIGENCE) OR STRICT LIABILITY, ARISING OUT OF OR IN CONNECTION
-   WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
-  
-   Pine and Pico are trademarks of the University of Washington.
-   No commercial use of these trademarks may be made without prior
-   written permission of the University of Washington.
+   Pine and Pico are registered trademarks of the University of Washington.
+   No commercial use of these trademarks may be made without prior written
+   permission of the University of Washington.
+
+   Pine, Pico, and Pilot software and its included text are Copyright
+   1989-1996 by the University of Washington.
+
+   The full text of our legal notices is contained in the file called
+   CPYRIGHT, included with this distribution.
+
 
    Pine is in part based on The Elm Mail System:
     ***********************************************************************
@@ -92,8 +81,8 @@
 
 
 /*----------------------------------------------------------------------
-    Turn this on if it's OK to encode sent message text containing
-  "From " at the beginning of any line.
+    Turn this on to trigger QP encoding of sent message text if it contains
+  "From " at the beginning of a line or "." on a line by itself.
  ----*/
 /* #define ENCODE_FROMS */
 
@@ -110,9 +99,11 @@
 /*----------------------------------------------------------------------
     Timeouts (seconds)
  ----*/
-#define NEW_MAIL_TIME      (150) /* How often to check for new mail. There's 
-                                   some expense in doing this so it shouldn't
-                                   be done too frequently.  */
+#define DF_MAILCHECK      "150" /* How often to check for new mail, by
+				   default.  There's some expense in doing
+				   this so it shouldn't be done too
+				   frequently.  (Can be set in config
+				   file now.)  */
 
 /*----------------------------------------------------------------------
     Check pointing (seconds)
@@ -136,7 +127,25 @@
  In scrolling through text, the number of lines from the previous
  screen to overlap when showing the next screen.  Usually set to two.
  ----*/
-#define	OVERLAP		(2) 
+#define	DF_OVERLAP	"2"
+
+
+
+/*----------------------------------------------------------------------
+ When scrolling screens, the number of lines from top and bottom of
+ the screen to initiate single-line scrolling.
+ ----*/
+#define	DF_MARGIN	"0"
+
+
+
+/*----------------------------------------------------------------------
+ Default fill column for pine composer and maximum fill column.  The max
+ is used to stop people from setting their custom fill column higher than
+ that number.  Note that DF_FILLCOL is a string but MAX_FILLCOL is an integer.
+ ----*/
+#define	DF_FILLCOL	"74"
+#define	MAX_FILLCOL	80
 
 
 
@@ -161,6 +170,7 @@
 #define POSTPONED_MAIL            "postpone"
 #define POSTPONED_MSGS            "postpond"
 #define INTERRUPTED_MAIL          "intruptd"
+#define DEADLETTER                "deadletr"
 #define	DF_FOLDER_EXTENSION	  "MTX"
 #define DF_MAIL_DIRECTORY         "mail"
 #define INBOX_NAME                "INBOX"
@@ -180,6 +190,13 @@
 #define DF_ADDRESSBOOK            "addrbook"
 #define DF_BUGS_FULLNAME          "Pine Developers"
 #define DF_BUGS_ADDRESS           "pine-bugs@cac.washington.edu"
+#define DF_SUGGEST_FULLNAME       "Pine Developers"
+#define DF_SUGGEST_ADDRESS        "pine-suggestions@cac.washington.edu"
+#define DF_PINEINFO_FULLNAME      "Pine-Info News Group"
+#define DF_PINEINFO_ADDRESS       "pine-info@cac.washington.edu"
+#define DF_LOCAL_FULLNAME         "Local Support"
+#define DF_LOCAL_ADDRESS          "postmaster"
+#define DF_KBLOCK_PASSWD_COUNT    "1"
 
 /*----------------------------------------------------------------------
    The default printer when pine starts up for the first time with no printer
@@ -233,6 +250,8 @@
 #include <netdb.h>
 #undef	signal				/* override their stupid def */
 #define	sleep	_sleep			/* use pico's sleep function */
+#undef	write				/* make way:c-client def's write */
+#undef	SIGCHLD
 #else
 #ifdef	LWP
 #include <sys/socket.h>			/* LanWorkplace Include Files */
@@ -246,6 +265,7 @@
 #else
 #include <tcp.h>			/* WATTCP Include File */
 #define	ENAMETOOLONG	0		/* unsupported errno value */
+#define	word	p_word			/* compensate for bad args labels */
 #endif
 #endif
 #endif
@@ -263,6 +283,11 @@
 
 
 
+/*----------------- locale.h -------------------------------------------*/
+/* #include <locale.h>  /* To make matching and sorting work right */
+
+
+
 /*----------------- time.h ---------------------------------------------*/
 #include <time.h>
 /* plain time.h isn't enough on some systems */
@@ -274,17 +299,23 @@
 #include <signal.h>
 /* #include <sys/signal.h> */
 
-#define SigType void
-/* #define SigType int */
+#define SigType void     /* value returned by sig handlers is void */
+/* #define SigType int      /* value returned by sig handlers is int */
 
 /* #define POSIX_SIGNALS */
 
-/*--- For AT&T-derviced systems ----------------------------------------*/
+/*--- For AT&T-derived systems ----------------------------------------*/
 /* #define signal(a,b) sigset (a, b) */
 /* extern void (*sigset())(); */
 
 
 
+/*-------------- A couple typedef's for integer sizes ------------------*/
+typedef unsigned long usign32_t;
+typedef unsigned short usign16_t;
+
+
+
 /*-------------- qsort argument type -----------------------------------*/
 #define QSType void
 /* #define QSType char */
@@ -309,10 +340,6 @@
 
 
 
-/*-- What argument does wait(2) take? Define this if it is a union -----*/
-/* #define HAVE_WAIT_UNION */
-
-
 /*-------- Is window resizing available? -------------------------------*/
 /* #define RESIZING */
 	/* Actually, under windows it is, but RESIZING compiles in UNIX 
@@ -352,12 +379,23 @@ extern  FILE    *append_file;
 
 
 
+/*----------------------------------------------------------------------
+    This is DOS specific and is used to fake the results of SIGALRM
+ signal handling without an alarm system call.
+ ----*/
+#define  ALARM_BLIP()  fake_alarm_blip()
+extern	unsigned alarm(unsigned);
+
+
+
 /*----- The usual sendmail configuration for sending mail on Unix ------*/
 /* #define SENDMAIL	"/usr/lib/sendmail" */
-/* #define SENDMAILFLAGS	"-oi -oem -t"	/* ignore dots in incoming mail,
-					   mail back errors, and
-					   get recipients from To, cc,
-					   and bcc header lines.      */
+/* #define SENDMAILFLAGS	"-bs -odb -oem"	/* send via smtp with backgroud
+					   delivery and mail back errors */
+
+
+/*--------- Program employed by users to change their password ---------*/
+/* #define	PASSWD_PROG	"" */
 
 
 /*-------------- A couple constants used to size arrays ----------------*/
