@@ -1,5 +1,5 @@
 /*----------------------------------------------------------------------
-  $Id: os-neb.h,v 4.20 1996/03/15 06:43:47 hubert Exp $
+  $Id: os-neb.h,v 4.22 1996/04/02 22:52:59 mikes Exp $
 
             T H E    P I N E    M A I L   S Y S T E M
 
@@ -123,6 +123,14 @@
 
 
 
+/*----------------------------------------------------------------------
+ When scrolling screens, the number of lines from top and bottom of
+ the screen to initiate single-line scrolling.
+ ----*/
+#define	DF_MARGIN	"0"
+
+
+
 /*----------------------------------------------------------------------
  Default fill column for pine composer and maximum fill column.  The max
  is used to stop people from setting their custom fill column higher than
@@ -213,6 +221,11 @@
 
 
 
+/*----------------- locale.h -------------------------------------------*/
+/* #include <locale.h>  /* To make matching and sorting work right */
+
+
+
 /*----------------- time.h ---------------------------------------------*/
 #include <time.h>
 /* plain time.h isn't enough on some systems */
