@@ -1,5 +1,5 @@
 #if !defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: pine.c,v 4.324 1996/03/15 07:13:42 hubert Exp $";
+static char rcsid[] = "$Id: pine.c,v 4.330 1996/04/09 22:42:18 mikes Exp $";
 #endif
 /*----------------------------------------------------------------------
 
@@ -43,7 +43,7 @@ static char rcsid[] = "$Id: pine.c,v 4.324 1996/03/15 07:13:42 hubert Exp $";
 
 
 /*
- * Handly local definitions...
+ * Handy local definitions...
  */
 #define	LEGAL_NOTICE \
    "Copyright 1989-1996.  PINE is a trademark of the University of Washington."
@@ -263,6 +263,17 @@ main(argc, argv)
     char stdiobuf[64];
 #endif
 
+#ifdef LC_COLLATE
+    /*
+     * This may not have the desired effect, if strcmp and friends
+     * don't know about it.
+     */
+    setlocale(LC_COLLATE, "");
+#endif
+#ifdef LC_CTYPE
+    setlocale(LC_CTYPE, "");
+#endif
+
     /*----------------------------------------------------------------------
           Set up buffering and some data structures
       ----------------------------------------------------------------------*/
@@ -426,20 +437,12 @@ main(argc, argv)
     if(!pine_state->nr_mode)
       write_pinerc(pine_state);
 
-    if(!pine_state->more_mode && *argv == NULL)
-      /*
-       * do mail dir if we're not in send only mode...
-       */
-      if(init_mail_dir(pine_state) < 0){
-#ifdef	_WINDOWS
-	  /* Under windows, the output goes to the window.  If we exit,
-	   * they will not have time to read the message.
-	   */
-	  mswin_flush ();
-	  mswin_pause (15);
-#endif
-	  exit(-1);
-      }
+    /*
+     * Verify mail dir if we're not in send only mode...
+     */
+    if(!pine_state->more_mode && *argv == NULL
+	&& init_mail_dir(pine_state) < 0)
+      exit(-1);
 
     init_signals();
 
@@ -604,6 +607,7 @@ main(argc, argv)
 
 	    fcc.tptr = NULL;
 	    fcc.next = NULL;
+	    fcc.xtra = NULL;
 	    good_addr = (build_address(to, &addr, &error, &fcc) >= 0);
 	}
 
@@ -1412,29 +1416,31 @@ main_menu_screen(pine_state)
 
 		mouse_get_last (NULL, &mp);
 		ndmi = mp.row - 3;
-		if (mp.row >= 3 && (ndmi ^ 0x01)
-		    && ndmi <= (unsigned)MAX_DEFAULT_MENU_ITEM) {
+		if (mp.row >= 3 && !(ndmi & 0x01)
+		    && ndmi <= (unsigned)MAX_DEFAULT_MENU_ITEM
+		    && ndmi < pine_state->ttyo->screen_rows
+				       - 4 - FOOTER_ROWS(ps_global)) {
 		    if(mp.doubleclick){
-			switch(mp.row){		/* fake main_screen request */
-			  case 3 :
+			switch(ndmi){		/* fake main_screen request */
+			  case 0 :
 			    goto help_case;
 
-			  case 5 :
+			  case 2 :
 			    goto compose_case;
 
-			  case 7 :
+			  case 4 :
 			    goto index_case;
 
-			  case 9 :
+			  case 6 :
 			    goto folder_case;
 
-			  case 11 :
+			  case 8 :
 			    goto addrbook_case;
 
-			  case 13 :
+			  case 10 :
 			    goto setup_case;
 
-			  case 15 :
+			  case 12 :
 			    goto quit_case;
 
 			  default:			/* no op */
@@ -2129,6 +2135,10 @@ goodnight_gracey(pine_state, exit_val)
 
     cur_is_inbox = (pine_state->inbox_stream == pine_state->mail_stream);
 
+    /* committed to exiting so become unreceptive to HUP */
+    end_sighup();
+
+    /* clean up open streams */
     if(pine_state->mail_stream)
       expunge_and_close(pine_state->mail_stream, pine_state->context_current,
 			pine_state->cur_folder,
@@ -2620,7 +2630,7 @@ panic(message)
     /* fprintf won't do a thing in windows.  Instead, put up a message
      * box. */
     sprintf (tmp_20k_buf, "Sorry, Problem detected.  %s.  Very Sorry, pine will now crash, please report this.", message);
-    mswin_messagebox (tmp_20k_buf);
+    mswin_messagebox (tmp_20k_buf, 1);
 #endif
 
 #ifdef DEBUG
